bibtex library
A simple parser that reads a BibTeX file into a list of BibTeX entries with a list of fields.
Classes
- BibTeXDefinition
- Grammar definition for BibTeX files.
- BibTeXEntry
- Models a single BibTeX bibliographic entry.
Functions
-
normalizeFieldName(
String name) → String - Normalizes a BibTeX field name by capitalizing the first letter and any letter immediately following a hyphen, lowercasing all other characters.
-
normalizeFieldValue(
String value) → String - Normalizes a raw BibTeX field value to a clean display string.