LispParserDefinition class

LISP parser definition that directly creates typed Lisp AST structures.

Constructors

LispParserDefinition()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

atom() → Parser
atomChoice() → Parser
bracket(String brackets, Parser parser) → Parser
build() → Parser<List>
Builds the default composite parser starting at start.
inherited
buildFrom<T>(Parser<T> parser) → Parser<T>
Builds a composite parser starting with the specified parser.
inherited
cell() → Parser<Cons>
cells() → Parser
character() → Parser<String>
characterEscape() → Parser<String>
characterRaw() → Parser<String>
comment() → Parser<void>
empty() → Parser
list() → Parser
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
number() → Parser<num>
numberToken() → Parser<void>
quasiquote() → Parser<Cons>
quote() → Parser<Quote>
space() → Parser<void>
splice() → Parser<Cons>
start() → Parser<List>
Returns the starting production of this definition.
string() → Parser<String>
symbol() → Parser<Name>
symbolToken() → Parser<void>
toString() → String
A string representation of this object.
inherited
unquote() → Parser<Cons>

Operators

operator ==(Object other) → bool
The equality operator.
inherited