HeadingNode class
An ATX or Setext heading with a level (1-6) and content.
Properties
-
content
→ InlineNode
-
The inline content inside this heading.
final
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
level
→ int
-
The heading depth, from 1 (
#) to 6 (######).
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
start
→ int?
-
The character offset where this node starts in the source, if tracked.
finalinherited
-
stop
→ int?
-
The character offset where this node stops in the source, if tracked.
finalinherited
Methods
-
accept<R>(MarkdownVisitor<R> visitor)
→ R
-
Dispatches to
visitor based on concrete node type.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override