HighlightSpan class

Represents a highlighted text range with an associated CSS class.

Implemented types

Constructors

HighlightSpan(int start, int stop, String cssClass)
const

Properties

cssClass → String
CSS class for syntax coloring.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
Start offset in source code.
final
stop → int
Stop offset in source code.
final

Methods

compareTo(HighlightSpan other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited