ImageNode class
An embedded image ().
- Inheritance
-
- Object
- MarkdownNode
- InlineNode
- ImageNode
Properties
- alt → InlineNode
-
The image alt text or nested inline nodes.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int?
-
The character offset where this node starts in the source, if tracked.
finalinherited
- stop → int?
-
The character offset where this node stops in the source, if tracked.
finalinherited
- title → String?
-
Optional image title.
final
- url → String
-
The image source URL.
final
Methods
-
accept<
R> (MarkdownVisitor< R> visitor) → R -
Dispatches to
visitorbased on concrete node type.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override