LineBreakNode class

A line break, either a hard break (<br />) or soft break (\n).

Inheritance

Constructors

LineBreakNode({bool isHard = false, int? start, int? stop})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
isHard → bool
Whether this is a hard line break (created with 2 trailing spaces or \).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int?
The character offset where this node starts in the source, if tracked.
finalinherited
stop → int?
The character offset where this node stops in the source, if tracked.
finalinherited

Methods

accept<R>(MarkdownVisitor<R> visitor) → R
Dispatches to visitor based on concrete node type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override