LinkReferenceDefinitionNode class

A link reference definition block ([label]: url "title").

Inheritance

Constructors

LinkReferenceDefinitionNode(String label, String url, {String? title, int? start, int? stop})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
label → String
The reference label case-folded for matching.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int?
The character offset where this node starts in the source, if tracked.
finalinherited
stop → int?
The character offset where this node stops in the source, if tracked.
finalinherited
title → String?
Optional link title.
final
url → String
The target destination URL.
final

Methods

accept<R>(MarkdownVisitor<R> visitor) → R
Dispatches to visitor based on concrete node type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override