ListItemNode class

An individual item inside an ordered or bullet list.

Inheritance

Constructors

ListItemNode(List<BlockNode> children, {bool? isTask, bool? isChecked, int? start, int? stop})
const

Properties

children → List<BlockNode>
The block-level contents of this list item.
final
hashCode → int
The hash code for this object.
no setteroverride
isChecked → bool?
If this is a task item, whether it is checked ([x]).
final
isTask → bool?
Whether this item is a GFM task list checkbox item.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int?
The character offset where this node starts in the source, if tracked.
finalinherited
stop → int?
The character offset where this node stops in the source, if tracked.
finalinherited

Methods

accept<R>(MarkdownVisitor<R> visitor) → R
Dispatches to visitor based on concrete node type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override