blankLine method
Matches an empty or blank line ending with a newline.
Implementation
Parser<String> blankLine() => seq2(
ref0(sp),
ref0(newlineSequence),
).flatten(message: 'blank line expected');
Matches an empty or blank line ending with a newline.
Parser<String> blankLine() => seq2(
ref0(sp),
ref0(newlineSequence),
).flatten(message: 'blank line expected');