indent method
Matches 4 spaces or a single horizontal tab representing an indentation.
Implementation
Parser<String> indent() => [string(' '), char('\t')].toChoiceParser();
Matches 4 spaces or a single horizontal tab representing an indentation.
Parser<String> indent() => [string(' '), char('\t')].toChoiceParser();