MarkdownHtmlRenderer class
Renders a MarkdownNode tree into an HTML string.
- Implemented types
Constructors
- MarkdownHtmlRenderer()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitAutolink(
AutolinkNode node) → String -
override
-
visitBlockquote(
BlockquoteNode node) → String -
override
-
visitBulletList(
BulletListNode node) → String -
override
-
visitCodeSpan(
CodeSpanNode node) → String -
override
-
visitCompositeInline(
CompositeInlineNode node) → String -
override
-
visitDocument(
DocumentNode node) → String -
override
-
visitEmphasis(
EmphasisNode node) → String -
override
-
visitFencedCodeBlock(
FencedCodeBlockNode node) → String -
override
-
visitHeading(
HeadingNode node) → String -
override
-
visitHtmlBlock(
HtmlBlockNode node) → String -
override
-
visitImage(
ImageNode node) → String -
override
-
visitIndentedCodeBlock(
IndentedCodeBlockNode node) → String -
override
-
visitLineBreak(
LineBreakNode node) → String -
override
-
visitLink(
LinkNode node) → String -
override
-
visitLinkReferenceDefinition(
LinkReferenceDefinitionNode node) → String -
override
-
visitListItem(
ListItemNode node) → String -
override
-
visitOrderedList(
OrderedListNode node) → String -
override
-
visitParagraph(
ParagraphNode node) → String -
override
-
visitRawHtmlInline(
RawHtmlInlineNode node) → String -
override
-
visitStrikethrough(
StrikethroughNode node) → String -
override
-
visitStrong(
StrongNode node) → String -
override
-
visitTable(
TableNode node) → String -
override
-
visitTableCell(
TableCellNode node) → String -
override
-
visitTableRow(
TableRowNode node) → String -
override
-
visitText(
TextNode node) → String -
override
-
visitThematicBreak(
ThematicBreakNode node) → String -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
escape(
String text) → String -
Escapes special HTML characters (
&,<,>,"). -
plainText(
InlineNode node) → String - Extracts unformatted plain text from an InlineNode (e.g. for img alt attributes).