MarkdownNode class sealed
Base class for all Abstract Syntax Tree (AST) nodes in Markdown.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int?
-
The character offset where this node starts in the source, if tracked.
final
- stop → int?
-
The character offset where this node stops in the source, if tracked.
final
Methods
-
accept<
R> (MarkdownVisitor< R> visitor) → R -
Dispatches to
visitorbased on concrete node type. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited