TableRowNode class

A row inside a TableNode.

Inheritance

Constructors

TableRowNode(List<TableCellNode> cells, {bool isHeader = false, int? start, int? stop})
const

Properties

cells → List<TableCellNode>
The cells in this row.
final
hashCode → int
The hash code for this object.
no setteroverride
isHeader → bool
Whether this row represents the header row (<th>).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int?
The character offset where this node starts in the source, if tracked.
finalinherited
stop → int?
The character offset where this node stops in the source, if tracked.
finalinherited

Methods

accept<R>(MarkdownVisitor<R> visitor) → R
Dispatches to visitor based on concrete node type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override