parseMarkdown function
Parses the input Markdown text into a strongly typed DocumentNode.
Implementation
DocumentNode parseMarkdown(String input) => _defaultParser.parse(input).value;
Parses the input Markdown text into a strongly typed DocumentNode.
DocumentNode parseMarkdown(String input) => _defaultParser.parse(input).value;