Expression class abstract

An abstract mathematical expression that can be evaluated.

Implementers

Constructors

Expression()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

eval(Map<String, num> variables) → num
Evaluates this expression using the variable bindings in variables.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited