Value class

A literal numeric value expression.

Inheritance

Constructors

Value(num value)
Creates a literal numeric value expression.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → num
The literal numeric value.
final

Methods

eval(Map<String, num> variables) → num
Evaluates this expression using the variable bindings in variables.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited