Variable class

A named variable expression resolved from a variable map.

Inheritance

Constructors

Variable(String name)
Creates a variable expression referencing name.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the variable to look up.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

eval(Map<String, num> variables) → num
Evaluates this expression using the variable bindings in variables.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited