ArrayTypeNode class

An array type, e.g. array [1..10] of Integer.

Inheritance

Constructors

ArrayTypeNode({required List<TypeNode> indices, required TypeNode elementType})
const

Properties

children → List<PascalNode>
Direct child nodes of this node.
no setteroverride
elementType → TypeNode
final
hashCode → int
The hash code for this object.
no setterinherited
indices → List<TypeNode>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<R, C>(PascalVisitor<R, C> visitor, [C? context]) → R
Accepts a visitor to traverse the AST.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited