CaseStatementNode class

A case statement: case expr of const: stmt; ... end.

Inheritance

Constructors

CaseStatementNode({String? label, required ExpressionNode expression, required List<CaseElementNode> cases})
const

Properties

cases → List<CaseElementNode>
final
children → List<PascalNode>
Direct child nodes of this node.
no setteroverride
expression → ExpressionNode
final
hashCode → int
The hash code for this object.
no setterinherited
label → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<R, C>(PascalVisitor<R, C> visitor, [C? context]) → R
Accepts a visitor to traverse the AST.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited