FieldAccessExpressionNode class
A record field access: rec.field.
- Inheritance
-
- Object
- PascalNode
- ExpressionNode
- FieldAccessExpressionNode
Constructors
- FieldAccessExpressionNode({required ExpressionNode record, required String field})
-
const
Properties
-
children
→ List<
PascalNode> -
Direct child nodes of this node.
no setteroverride
- field → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- record → ExpressionNode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept<
R, C> (PascalVisitor< R, C> visitor, [C? context]) → R -
Accepts a visitor to traverse the AST.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited