FormalParameterNode class

A formal parameter in a procedure or function heading.

Inheritance

Constructors

FormalParameterNode({required List<String> names, TypeNode? type, bool isVar = false, bool isFunction = false, bool isProcedure = false})
const

Properties

children → List<PascalNode>
Direct child nodes of this node.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isFunction → bool
final
isProcedure → bool
final
isVar → bool
final
names → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TypeNode?
final

Methods

accept<R, C>(PascalVisitor<R, C> visitor, [C? context]) → R
Accepts a visitor to traverse the AST.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited