FunctionNode class

A function declaration.

Inheritance

Constructors

FunctionNode({required String name, List<FormalParameterNode> parameters = const [], required TypeNode returnType, required BlockNode block})
const

Properties

block → BlockNode
final
children → List<PascalNode>
Direct child nodes of this node.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
parameters → List<FormalParameterNode>
final
returnType → TypeNode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<R, C>(PascalVisitor<R, C> visitor, [C? context]) → R
Accepts a visitor to traverse the AST.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited