IfStatementNode class
An if statement: if condition then thenStatement [else elseStatement].
- Inheritance
-
- Object
- PascalNode
- StatementNode
- IfStatementNode
Constructors
- IfStatementNode({String? label, required ExpressionNode condition, required StatementNode thenStatement, StatementNode? elseStatement})
-
const
Properties
-
children
→ List<
PascalNode> -
Direct child nodes of this node.
no setteroverride
- condition → ExpressionNode
-
final
- elseStatement → StatementNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thenStatement → StatementNode
-
final
Methods
-
accept<
R, C> (PascalVisitor< R, C> visitor, [C? context]) → R -
Accepts a visitor to traverse the AST.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited