Visitor interface for PascalNode AST hierarchies.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitArrayAccessExpression(
ArrayAccessExpressionNode node, C? context) → R -
visitArrayType(
ArrayTypeNode node, C? context) → R -
visitAssignmentStatement(
AssignmentStatementNode node, C? context) → R -
visitBinaryExpression(
BinaryExpressionNode node, C? context) → R -
visitBlock(
BlockNode node, C? context) → R -
visitCaseElement(
CaseElementNode node, C? context) → R -
visitCaseStatement(
CaseStatementNode node, C? context) → R -
visitCompoundStatement(
CompoundStatementNode node, C? context) → R -
visitConstantDefinition(
ConstantDefinitionNode node, C? context) → R -
visitEmptyStatement(
EmptyStatementNode node, C? context) → R -
visitEnumeratedType(
EnumeratedTypeNode node, C? context) → R -
visitFieldAccessExpression(
FieldAccessExpressionNode node, C? context) → R -
visitFileType(
FileTypeNode node, C? context) → R -
visitFormalParameter(
FormalParameterNode node, C? context) → R -
visitForStatement(
ForStatementNode node, C? context) → R -
visitFunction(
FunctionNode node, C? context) → R -
visitFunctionCallExpression(
FunctionCallExpressionNode node, C? context) → R -
visitGotoStatement(
GotoStatementNode node, C? context) → R -
visitIfStatement(
IfStatementNode node, C? context) → R -
visitLiteralExpression(
LiteralExpressionNode node, C? context) → R -
visitPointerDereferenceExpression(
PointerDereferenceExpressionNode node, C? context) → R -
visitPointerType(
PointerTypeNode node, C? context) → R -
visitProcedure(
ProcedureNode node, C? context) → R -
visitProcedureStatement(
ProcedureStatementNode node, C? context) → R -
visitProgram(
ProgramNode node, C? context) → R -
visitRecordType(
RecordTypeNode node, C? context) → R -
visitRepeatStatement(
RepeatStatementNode node, C? context) → R -
visitSetElement(
SetElementNode node, C? context) → R -
visitSetExpression(
SetExpressionNode node, C? context) → R -
visitSetType(
SetTypeNode node, C? context) → R -
visitSimpleType(
SimpleTypeNode node, C? context) → R -
visitSubrangeType(
SubrangeTypeNode node, C? context) → R -
visitTypeDefinition(
TypeDefinitionNode node, C? context) → R -
visitUnaryExpression(
UnaryExpressionNode node, C? context) → R -
visitVariableDeclaration(
VariableDeclarationNode node, C? context) → R -
visitVariableExpression(
VariableExpressionNode node, C? context) → R -
visitWhileStatement(
WhileStatementNode node, C? context) → R -
visitWithStatement(
WithStatementNode node, C? context) → R
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited