RepeatStatementNode class

A repeat loop: repeat s1; s2 until condition.

Inheritance

Constructors

RepeatStatementNode({String? label, required List<StatementNode> statements, required ExpressionNode condition})
const

Properties

children → List<PascalNode>
Direct child nodes of this node.
no setteroverride
condition → ExpressionNode
final
hashCode → int
The hash code for this object.
no setterinherited
label → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statements → List<StatementNode>
final

Methods

accept<R, C>(PascalVisitor<R, C> visitor, [C? context]) → R
Accepts a visitor to traverse the AST.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited