Node class abstract

Base class for all Prolog AST terms and variables.

Supports unification via match and variable substitution via substitute.

Implementers
Annotations
  • @immutable

Constructors

Node()
Const constructor for subclasses.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

match(Node other) → Map<Variable, Node>?
Attempts to unify this node with other, returning variable bindings or null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
substitute(Map<Variable, Node>? bindings) → Node
Substitutes variables in this node with their bound values in bindings.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited