PrologParserDefinition class

Grammar definition that produces typed Prolog AST structures.

Constructors

PrologParserDefinition()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → Map<String, Variable>
final

Methods

atom() → Parser<Node>
build() → Parser<List<Rule>>
Builds the default composite parser starting at start.
inherited
buildFrom<T>(Parser<T> parser) → Parser<T>
Builds a composite parser starting with the specified parser.
inherited
commentMulti() → Parser<void>
commentSingle() → Parser<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameter() → Parser<Node>
rule() → Parser<Rule>
rules() → Parser<List<Rule>>
space() → Parser<void>
start() → Parser<List<Rule>>
Returns the starting production of this definition.
term() → Parser<Term>
token(Object parser, [String? message]) → Parser<String>
toString() → String
A string representation of this object.
inherited
value() → Parser<Value>
valueToken() → Parser<String>
variable() → Parser<Variable>
variableToken() → Parser<String>

Operators

operator ==(Object other) → bool
The equality operator.
inherited