AnnAssignNode class

Annotated assignment statement (x: int = 1).

Inheritance

Constructors

AnnAssignNode({required ExpressionNode target, required ExpressionNode annotation, ExpressionNode? value})
const

Properties

annotation → ExpressionNode
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → ExpressionNode
final
value → ExpressionNode?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited