ArgumentsNode class
Function parameter list (def foo(a, b=1, *args, c=2, **kwargs):).
- Inheritance
-
- Object
- PythonNode
- ArgumentsNode
Constructors
-
ArgumentsNode({List<
ArgNode> posonlyargs = const [], List<ArgNode> args = const [], ArgNode? vararg, List<ArgNode> kwonlyargs = const [], List<ExpressionNode?> kwDefaults = const [], ArgNode? kwarg, List<ExpressionNode> defaults = const []}) -
const
Properties
-
args
→ List<
ArgNode> -
final
-
defaults
→ List<
ExpressionNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kwarg → ArgNode?
-
final
-
kwDefaults
→ List<
ExpressionNode?> -
final
-
kwonlyargs
→ List<
ArgNode> -
final
-
posonlyargs
→ List<
ArgNode> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vararg → ArgNode?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited