AssertNode class
Assert statement (assert test, msg).
- Inheritance
-
- Object
- PythonNode
- StatementNode
- AssertNode
Constructors
- AssertNode({required ExpressionNode test, ExpressionNode? msg})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- msg → ExpressionNode?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- test → ExpressionNode
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited