AssignNode class

Assignment statement (x = y = 1).

Inheritance

Constructors

AssignNode({required List<ExpressionNode> targets, required ExpressionNode value})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targets → List<ExpressionNode>
final
value → ExpressionNode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited