AsyncWithNode class

Async with statement (async with item1: body).

Inheritance

Constructors

AsyncWithNode({required List<WithItemNode> items, required List<StatementNode> body})
const

Properties

body → List<StatementNode>
final
hashCode → int
The hash code for this object.
no setterinherited
items → List<WithItemNode>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited