AttributeNode class
Attribute access (value.attr).
- Inheritance
-
- Object
- PythonNode
- ExpressionNode
- AttributeNode
Constructors
- AttributeNode({required ExpressionNode value, required String attribute})
-
const
Properties
- attribute → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → ExpressionNode
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited