CallNode class

Function / method call expression (f(a, b, c=1)).

Inheritance

Constructors

CallNode({required ExpressionNode function, List<ExpressionNode> args = const [], List<KeywordNode> keywords = const []})
const

Properties

args → List<ExpressionNode>
final
function → ExpressionNode
final
hashCode → int
The hash code for this object.
no setterinherited
keywords → List<KeywordNode>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited