ClassDefNode class

Class definition statement (class Name(bases): body).

Inheritance

Constructors

ClassDefNode({required String name, required List<StatementNode> body, List<ExpressionNode> bases = const [], List<KeywordNode> keywords = const [], List<ExpressionNode> decoratorList = const [], List<TypeParamNode> typeParams = const []})
const

Properties

bases → List<ExpressionNode>
final
body → List<StatementNode>
final
decoratorList → List<ExpressionNode>
final
hashCode → int
The hash code for this object.
no setterinherited
keywords → List<KeywordNode>
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeParams → List<TypeParamNode>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited