CompareNode class

Comparison expression with chaining support (a < b <= c).

Inheritance

Constructors

CompareNode({required ExpressionNode left, required List<String> operators, required List<ExpressionNode> comparators})
const

Properties

comparators → List<ExpressionNode>
final
hashCode → int
The hash code for this object.
no setterinherited
left → ExpressionNode
final
operators → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited