ComprehensionNode class
Comprehension clause (for target in iter if cond).
- Inheritance
-
- Object
- PythonNode
- ComprehensionNode
Constructors
-
ComprehensionNode({required ExpressionNode target, required ExpressionNode iter, List<
ExpressionNode> ifs = const [], bool isAsync = false}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ifs
→ List<
ExpressionNode> -
final
- isAsync → bool
-
final
- iter → ExpressionNode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → ExpressionNode
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited