DictCompNode class

Dict comprehension ({k: v for k, v in data}).

Inheritance

Constructors

DictCompNode({required ExpressionNode key, required ExpressionNode value, required List<ComprehensionNode> generators})
const

Properties

generators → List<ComprehensionNode>
final
hashCode → int
The hash code for this object.
no setterinherited
key → ExpressionNode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → ExpressionNode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited