ExceptHandlerNode class

Except handler in try statement (except Error as e:).

Inheritance

Constructors

ExceptHandlerNode({ExpressionNode? type, String? name, required List<StatementNode> body})
const

Properties

body → List<StatementNode>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ExpressionNode?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited