ExprStatementNode class
An expression evaluated as a statement.
- Inheritance
-
- Object
- PythonNode
- StatementNode
- ExprStatementNode
Constructors
- ExprStatementNode(ExpressionNode value)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → ExpressionNode
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited