ExpressionNode class sealed
Base class for all Python expressions.
- Inheritance
-
- Object
- PythonNode
- ExpressionNode
- Implementers
- AttributeNode
- AwaitNode
- BinOpNode
- BoolOpNode
- CallNode
- CompareNode
- ConstantNode
- DictCompNode
- DictNode
- FormattedValueNode
- GeneratorExpNode
- IfExpNode
- JoinedStrNode
- LambdaNode
- ListCompNode
- ListNode
- NamedExprNode
- NameNode
- SetCompNode
- SetNode
- SliceNode
- StarredNode
- SubscriptNode
- TupleNode
- UnaryOpNode
- YieldFromNode
- YieldNode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited