ForNode class
For loop statement (for x in iter: body else: orelse).
- Inheritance
-
- Object
- PythonNode
- StatementNode
- ForNode
Constructors
-
ForNode({required ExpressionNode target, required ExpressionNode iter, required List<
StatementNode> body, List<StatementNode> orelse = const []}) -
const
Properties
-
body
→ List<
StatementNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iter → ExpressionNode
-
final
-
orelse
→ List<
StatementNode> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → ExpressionNode
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited