FormattedValueNode class

Formatted value inside an f-string ({x!r:.2f}).

Inheritance

Constructors

FormattedValueNode({required ExpressionNode value, String? conversion, String? formatSpec})
const

Properties

conversion → String?
final
formatSpec → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → ExpressionNode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited