JoinedStrNode class

Joined f-string (f"hello {name}").

Inheritance

Constructors

JoinedStrNode(List<ExpressionNode> values)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<ExpressionNode>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited