LambdaNode class

Lambda expression (lambda x, y: x + y).

Inheritance

Constructors

LambdaNode({required ArgumentsNode args, required ExpressionNode body})
const

Properties

args → ArgumentsNode
final
body → ExpressionNode
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited