MatchClassNode class

Class pattern (case Point(x, y, z=0):).

Inheritance

Constructors

MatchClassNode({required ExpressionNode cls, List<PatternNode> patterns = const [], List<String> kwdAttrs = const [], List<PatternNode> kwdPatterns = const []})
const

Properties

cls → ExpressionNode
final
hashCode → int
The hash code for this object.
no setterinherited
kwdAttrs → List<String>
final
kwdPatterns → List<PatternNode>
final
patterns → List<PatternNode>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited