MatchNode class

Pattern match statement (match subject: case ...).

Inheritance

Constructors

MatchNode({required ExpressionNode subject, required List<MatchCaseNode> cases})
const

Properties

cases → List<MatchCaseNode>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → ExpressionNode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited