MatchOrNode class

Or-pattern (case p1 | p2 | p3:).

Inheritance

Constructors

MatchOrNode(List<PatternNode> patterns)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
patterns → List<PatternNode>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited