ModuleNode class

A standard Python module consisting of a sequence of statements.

Inheritance

Constructors

ModuleNode({List<StatementNode> body = const []})
const

Properties

body → List<StatementNode>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited