suite method
Suite / Block of statements: either a simple inline statement or an indented block of statements.
Implementation
@override
Parser<List<StatementNode>> suite() =>
[ref0(indentedBlock), ref0(simpleStatements)].toChoiceParser();
Suite / Block of statements: either a simple inline statement or an indented block of statements.
@override
Parser<List<StatementNode>> suite() =>
[ref0(indentedBlock), ref0(simpleStatements)].toChoiceParser();