RaiseNode class

Raise statement (raise exc from cause).

Inheritance

Constructors

RaiseNode({ExpressionNode? exc, ExpressionNode? cause})
const

Properties

cause → ExpressionNode?
final
exc → ExpressionNode?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited