SetNode class

Set literal ({1, 2, 3}).

Inheritance

Constructors

SetNode({List<ExpressionNode> elements = const []})
const

Properties

elements → List<ExpressionNode>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited