SliceNode class

Slice expression used in subscripts (lower:upper:step).

Inheritance

Constructors

SliceNode({ExpressionNode? lower, ExpressionNode? upper, ExpressionNode? step})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lower → ExpressionNode?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
step → ExpressionNode?
final
upper → ExpressionNode?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited