StatementNode class sealed
Base class for all Python statements.
- Inheritance
-
- Object
- PythonNode
- StatementNode
- Implementers
- AnnAssignNode
- AssertNode
- AssignNode
- AsyncForNode
- AsyncFunctionDefNode
- AsyncWithNode
- AugAssignNode
- BreakNode
- ClassDefNode
- ContinueNode
- DeleteNode
- ExprStatementNode
- ForNode
- FunctionDefNode
- GlobalNode
- IfNode
- ImportFromNode
- ImportNode
- MatchNode
- NonlocalNode
- PassNode
- RaiseNode
- ReturnNode
- TryNode
- TryStarNode
- TypeAliasNode
- WhileNode
- WithNode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited