SubscriptNode class
Subscript indexing or slicing (value[slice]).
- Inheritance
-
- Object
- PythonNode
- ExpressionNode
- SubscriptNode
Constructors
- SubscriptNode({required ExpressionNode value, required ExpressionNode slice})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slice → ExpressionNode
-
final
- value → ExpressionNode
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited