TryStarNode class

Try-star statement (try: ... except* ExceptionGroup: ...).

Inheritance

Constructors

TryStarNode({required List<StatementNode> body, List<ExceptHandlerNode> handlers = const [], List<StatementNode> orelse = const [], List<StatementNode> finalbody = const []})
const

Properties

body → List<StatementNode>
final
finalbody → List<StatementNode>
final
handlers → List<ExceptHandlerNode>
final
hashCode → int
The hash code for this object.
no setterinherited
orelse → List<StatementNode>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited