TypeVarParamNode class

Simple type variable (T: str = int).

Inheritance

Constructors

TypeVarParamNode(String name, {ExpressionNode? bound, ExpressionNode? defaultValue})
const

Properties

bound → ExpressionNode?
final
defaultValue → ExpressionNode?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited