WithItemNode class

With item (context_expr as optional_vars).

Inheritance

Constructors

WithItemNode({required ExpressionNode contextExpr, ExpressionNode? optionalVars})
const

Properties

contextExpr → ExpressionNode
final
hashCode → int
The hash code for this object.
no setterinherited
optionalVars → ExpressionNode?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited