parsePython function
Parses the input Python source code into a ModuleNode.
Implementation
ModuleNode parsePython(String input) =>
PythonGrammarDefinition().build().parse(input).value;
Parses the input Python source code into a ModuleNode.
ModuleNode parsePython(String input) =>
PythonGrammarDefinition().build().parse(input).value;