AlternationNode class

An AST node matching either left or right (the | operator).

Inheritance

Constructors

AlternationNode(Node left, Node right)
Creates an alternation between left and right.

Properties

hashCode → int
The hash code for this object.
no setteroverride
left → Node
The alternative branch on the left.
final
The alternative branch on the right.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNfa() → Nfa
Compiles this AST node into a nondeterministic finite automaton (Nfa).
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override