ComplementNode class

An AST node matching the complement of child (inverting matches).

Inheritance

Constructors

ComplementNode(Node child)
Creates a complement node inverting matches of child.

Properties

child → Node
The child node whose matches are complemented.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNfa() → Nfa
Compiles this AST node into a nondeterministic finite automaton (Nfa).
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override