IntersectionNode class

An AST node matching the intersection of left and right (the & operator).

Note: Compilation to an Nfa is currently unsupported for intersection nodes.

Inheritance

Constructors

IntersectionNode(Node left, Node right)
Creates an intersection of left and right.

Properties

hashCode → int
The hash code for this object.
no setteroverride
left → Node
The first intersecting expression.
final
The second intersecting expression.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNfa() → Nfa
Compiles this AST node into a nondeterministic finite automaton (Nfa).
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override