LiteralNode constructor
LiteralNode(
- String literal
Creates a literal node matching the single character literal.
Implementation
new(String literal) : codePoint = literal.codeUnits.single;
Creates a literal node matching the single character literal.
new(String literal) : codePoint = literal.codeUnits.single;