ArrayNode class

An AST node representing a runtime dynamic array expression ({ 1 + 2. 'hello' }).

Inheritance
Mixed-in types

Constructors

ArrayNode()
Creates a dynamic array node.

Properties

afterToken → List<Token>
Closing boundary tokens.
finalinherited
beforeToken → List<Token>
Opening boundary tokens.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
periods → List<Token>
The period tokens separating statements.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statements → List<IsStatement>
The statements contained within this node.
finalinherited

Methods

accept(Visitor visitor) → void
Dispatches execution to visitor based on concrete node type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
surroundWith(Token before, Token after) → void
Records enclosing before and after tokens.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited