CascadeNode class
An AST node representing a message cascade (receiver msg1; msg2).
Constructors
- CascadeNode()
- Creates a cascade node.
Properties
-
afterToken
→ List<
Token> -
Closing boundary tokens.
finalinherited
-
beforeToken
→ List<
Token> -
Opening boundary tokens.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ List<
MessageNode> -
The cascaded messages sent to the receiver.
final
- receiver → ValueNode
-
The common receiver of all messages in the cascade.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
semicolons
→ List<
Token> -
Semicolon tokens separating cascaded messages.
final
Methods
-
accept(
Visitor visitor) → void -
Dispatches execution to
visitorbased on concrete node type.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
surroundWith(
Token before, Token after) → void -
Records enclosing
beforeandaftertokens.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited