LiteralArrayNode<T> class

An AST node representing a literal array constant (#(1 2 'three') or #[1 2 3]).

Inheritance

Constructors

LiteralArrayNode(List<LiteralNode<T>> values)
Creates a literal array node with element values.

Properties

afterToken → List<Token>
Closing boundary tokens.
finalinherited
beforeToken → List<Token>
Opening boundary tokens.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → List<T>
The literal value.
finalinherited
values → List<LiteralNode<T>>
The literal element nodes within this array.
final

Methods

accept(Visitor visitor) → void
Dispatches execution to visitor based on concrete node type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
surroundWith(Token before, Token after) → void
Records enclosing before and after tokens.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited