LiteralNode<T> class abstract

Inheritance
Implementers

Constructors

LiteralNode(T value)

Properties

afterToken → List<Token>
finalinherited
beforeToken → List<Token>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → T
final

Methods

accept(Visitor visitor) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
surroundWith(Token before, Token after) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited