LiteralValueNode<T> class
An AST node representing an atomic literal value (numbers, strings, booleans, symbols, nil).
- Inheritance
-
- Object
- Node
- ValueNode
- LiteralNode<
T> - LiteralValueNode
Constructors
- LiteralValueNode(Token token, T value)
-
Creates a literal value node from
tokenand parsedvalue.
Properties
-
afterToken
→ List<
Token> -
Closing boundary tokens.
finalinherited
-
beforeToken
→ List<
Token> -
Opening boundary tokens.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → Token
-
The source token representing this literal.
final
- value → T
-
The literal value.
finalinherited
Methods
-
accept(
Visitor visitor) → void -
Dispatches execution to
visitorbased on concrete node type.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
surroundWith(
Token before, Token after) → void -
Records enclosing
beforeandaftertokens.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited