Node class abstract

Abstract base class for all Smalltalk Abstract Syntax Tree (AST) nodes.

Implementers

Constructors

Node()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept(Visitor visitor) → void
Dispatches execution to visitor based on concrete node type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited