ReturnNode class

An AST node representing a method return statement (^ value).

Inheritance
Mixed-in types

Constructors

ReturnNode(Token caret, ValueNode value)
Creates a return statement with caret token caret and returned value.

Properties

caret → Token
The caret (^) token.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → ValueNode
The expression being returned.
final

Methods

accept(Visitor visitor) → void
Dispatches execution to visitor based on concrete node type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited