ReturnNode constructor
ReturnNode(
- Token caret,
- ValueNode value
Creates a return statement with caret token caret and returned value.
Implementation
new(this.caret, this.value);
Creates a return statement with caret token caret and returned value.
new(this.caret, this.value);