VariableNode class

An AST node representing a variable reference.

Inheritance

Constructors

VariableNode(Token token)
Creates a variable node with identifier token.

Properties

afterToken → List<Token>
Closing boundary tokens.
finalinherited
beforeToken → List<Token>
Opening boundary tokens.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The identifier name of the variable.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → Token
The token representing the variable identifier.
final

Methods

accept(Visitor visitor) → void
Dispatches execution to visitor based on concrete node type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
surroundWith(Token before, Token after) → void
Records enclosing before and after tokens.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited