BibTeXEntry class
Models a single BibTeX bibliographic entry.
Contains the entry type (e.g. 'article', 'book'), citation key,
and a map of fields.
For example:
final entry = BibTeXEntry(
type: 'article',
key: 'knuth1984',
fields: {'author': 'Donald E. Knuth', 'title': 'Literate Programming'},
);
print(entry.key); // 'knuth1984'
print(entry.normalized['Title']); // 'Literate Programming'
- Annotations
-
- @immutable
Constructors
Properties
-
fields
→ Map<
String, String> -
The raw key-value mapping of field names to values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
The unique citation key used to cite this entry.
final
-
normalized
→ Map<
String, String> -
The normalized fields with standardized names and LaTeX accents converted.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The entry type (e.g.
'article','inproceedings','book').final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited