MarkdownHighlighter class
A syntax highlighter for Markdown source code that uses AST position tokens.
Traverses the MarkdownNode AST produced by MarkdownGrammarDefinition to extract highlight spans without any regular expressions or duplicate grammars.
Constructors
- MarkdownHighlighter()
-
Creates a new MarkdownHighlighter instance.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
highlight(
String source) → String -
Highlights
sourceMarkdown into HTML with syntax spans. -
highlightAst(
MarkdownNode node, String source) → String -
Highlights
sourceusing the already parsednodeAST. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited