OrderedListNode class
An ordered enumerated list (1., 2.).
- Inheritance
-
- Object
- MarkdownNode
- BlockNode
- OrderedListNode
Constructors
-
OrderedListNode(List<
ListItemNode> items, {int startNumber = 1, bool isTight = true, int? start, int? stop}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isTight → bool
-
Whether spacing between items is tight.
final
-
items
→ List<
ListItemNode> -
The list items.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int?
-
The character offset where this node starts in the source, if tracked.
finalinherited
- startNumber → int
-
The starting integer number.
final
- stop → int?
-
The character offset where this node stops in the source, if tracked.
finalinherited
Methods
-
accept<
R> (MarkdownVisitor< R> visitor) → R -
Dispatches to
visitorbased on concrete node type.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override