TableNode class
A GFM table with rows and column alignments.
- Inheritance
-
- Object
- MarkdownNode
- BlockNode
- TableNode
Constructors
-
TableNode(List<
TableRowNode> rows, List<TableAlignment> alignments, {int? start, int? stop}) -
const
Properties
-
alignments
→ List<
TableAlignment> -
The column alignments.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
rows
→ List<
TableRowNode> -
All rows in the table, where the first row is typically the header.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int?
-
The character offset where this node starts in the source, if tracked.
finalinherited
- stop → int?
-
The character offset where this node stops in the source, if tracked.
finalinherited
Methods
-
accept<
R> (MarkdownVisitor< R> visitor) → R -
Dispatches to
visitorbased on concrete node type.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override