Application class
A function or operator application expression.
- Inheritance
-
- Object
- Expression
- Application
Constructors
-
Application(String name, List<
Expression> arguments, Function function) -
Creates a function application with
name,arguments, and evaluationfunction.
Properties
-
arguments
→ List<
Expression> -
The argument expressions passed to the function.
final
- function → Function
-
The underlying Dart function used to evaluate this application.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the operator or function.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
eval(
Map< String, num> variables) → num -
Evaluates this expression using the variable bindings in
variables.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited