BlockNode class
A Pascal block containing declarations and a compound statement.
- Inheritance
-
- Object
- PascalNode
- BlockNode
Constructors
-
BlockNode({List<
String> labels = const [], List<ConstantDefinitionNode> constants = const [], List<TypeDefinitionNode> types = const [], List<VariableDeclarationNode> variables = const [], List<PascalNode> subroutines = const [], required CompoundStatementNode statement}) -
const
Properties
-
children
→ List<
PascalNode> -
Direct child nodes of this node.
no setteroverride
-
constants
→ List<
ConstantDefinitionNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statement → CompoundStatementNode
-
final
-
subroutines
→ List<
PascalNode> -
final
-
types
→ List<
TypeDefinitionNode> -
final
-
variables
→ List<
VariableDeclarationNode> -
final
Methods
-
accept<
R, C> (PascalVisitor< R, C> visitor, [C? context]) → R -
Accepts a visitor to traverse the AST.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited