CaseElementNode class
A single element in a case statement: const1, const2: stmt.
- Inheritance
-
- Object
- PascalNode
- CaseElementNode
Constructors
-
CaseElementNode({required List<
ExpressionNode> constants, required StatementNode statement}) -
const
Properties
-
children
→ List<
PascalNode> -
Direct child nodes of this node.
no setteroverride
-
constants
→ List<
ExpressionNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statement → StatementNode
-
final
Methods
-
accept<
R, C> (PascalVisitor< R, C> visitor, [C? context]) → R -
Accepts a visitor to traverse the AST.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited