ForStatementNode class
A for loop: for variable := initial to/downto final do statement.
- Inheritance
-
- Object
- PascalNode
- StatementNode
- ForStatementNode
Constructors
- ForStatementNode({String? label, required String variable, required ExpressionNode initialValue, required bool isDownTo, required ExpressionNode finalValue, required StatementNode statement})
-
const
Properties
-
children
→ List<
PascalNode> -
Direct child nodes of this node.
no setteroverride
- finalValue → ExpressionNode
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → ExpressionNode
-
final
- isDownTo → bool
-
final
- label → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statement → StatementNode
-
final
- variable → String
-
final
Methods
-
accept<
R, C> (PascalVisitor< R, C> visitor, [C? context]) → R -
Accepts a visitor to traverse the AST.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited