PascalParserDefinition class
Pascal parser definition producing strongly typed PascalNode AST nodes.
Based on the Apple Pascal Standard: http://www.danamania.com/print/Apple%20Pascal%20Poster/PascalPosterV3%20A1.pdf
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
block(
) → Parser< BlockNode> -
blockConst(
) → Parser< List< ConstantDefinitionNode> > -
blockFunction(
) → Parser< FunctionNode> -
blockLabel(
) → Parser< List< String> > -
blockProcedure(
) → Parser< ProcedureNode> -
blockStatement(
) → Parser< CompoundStatementNode> -
blockType(
) → Parser< List< TypeDefinitionNode> > -
blockVar(
) → Parser< List< VariableDeclarationNode> > -
build(
) → Parser< ProgramNode> -
Builds the default composite parser starting at
start.inherited -
buildFrom<
T> (Parser< T> parser) → Parser<T> -
Builds a composite parser starting with the specified
parser.inherited -
comment(
) → Parser< void> -
constant(
) → Parser< LiteralExpressionNode> -
expression(
) → Parser< ExpressionNode> -
factor(
) → Parser< ExpressionNode> -
fieldList(
) → Parser< List< VariableDeclarationNode> > -
fieldListBase(
) → Parser< List< VariableDeclarationNode> > -
fieldListCase(
) → Parser< void> -
identifier(
) → Parser< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parameterList(
) → Parser< List< FormalParameterNode> ?> -
program(
) → Parser< ProgramNode> -
simpleExpression(
) → Parser< ExpressionNode> -
simpleType(
) → Parser< TypeNode> -
spacer(
) → Parser< void> -
start(
) → Parser< ProgramNode> - Returns the starting production of this definition.
-
statement(
) → Parser< StatementNode> -
statementAssign(
) → Parser< AssignmentStatementNode> -
statementBlock(
) → Parser< CompoundStatementNode> -
statementCall(
) → Parser< ProcedureStatementNode> -
statementCase(
) → Parser< CaseStatementNode> -
statementExit(
) → Parser< ProcedureStatementNode> -
statementFor(
) → Parser< ForStatementNode> -
statementGoto(
) → Parser< GotoStatementNode> -
statementIf(
) → Parser< IfStatementNode> -
statementLabel(
) → Parser< String> -
statementRepeat(
) → Parser< RepeatStatementNode> -
statementWhile(
) → Parser< WhileStatementNode> -
statementWith(
) → Parser< WithStatementNode> -
stringLiteral(
) → Parser< String> -
term(
) → Parser< ExpressionNode> -
token(
String string) → Parser< String> -
toString(
) → String -
A string representation of this object.
inherited
-
type(
) → Parser< TypeNode> -
typeArray(
) → Parser< ArrayTypeNode> -
typeFile(
) → Parser< FileTypeNode> -
typePointer(
) → Parser< PointerTypeNode> -
typeRecord(
) → Parser< RecordTypeNode> -
typeSet(
) → Parser< SetTypeNode> -
unsignedConstant(
) → Parser< LiteralExpressionNode> -
unsignedInteger(
) → Parser< int> -
unsignedNumber(
) → Parser< num> -
variable(
) → Parser< ExpressionNode>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited