Conjunction class
A conjunction of goals (the , operator in Prolog) evaluated sequentially.
For example:
final conj = Conjunction([
Term('parent', [Variable('X'), Variable('Y')]),
Term('parent', [Variable('Y'), Variable('Z')]),
]);
Constructors
-
Conjunction(Iterable<
Node> list) -
Creates a conjunction from an iterable
listof goal nodes.factory
Properties
Methods
-
match(
Node other) → Map< Variable, Node> ? -
Attempts to unify this node with
other, returning variable bindings ornull.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
Database database) → Iterable< Node> -
Evaluates this term as a goal against
database.override -
substitute(
Map< Variable, Node> ? bindings) → Conjunction -
Substitutes variables in this node with their bound values in
bindings.override -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override