Rule class final
A Prolog Horn clause consisting of a head term and a body goal.
Unconditional facts are represented with a body of True.
For example:
final rule = Rule(
Term('mortal', [Variable('X')]),
Term('human', [Variable('X')]),
);
- Annotations
-
- @immutable
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
Database database, Term goal) → Iterable< Node> -
Evaluates this rule against
databaseto satisfygoal. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited