Term class
A compound Prolog term consisting of a functor name and argument arguments.
When arguments is empty, represents an atomic term.
For example:
final term = Term.parse('father(john, mary)');
print(term.name); // 'father'
print(term.arguments); // [john, mary]
- Inheritance
- Implementers
- Annotations
-
- @immutable
Constructors
Properties
Methods
-
match(
Node other) → Map< Variable, Node> ? -
Attempts to unify this node with
other, returning variable bindings ornull.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
Database database) → Iterable< Node> -
Evaluates this term as a goal against
database. -
substitute(
Map< Variable, Node> ? bindings) → Term -
Substitutes variables in this node with their bound values in
bindings.override -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override