Value class
A Prolog atomic constant (atom) with no arguments.
For example:
const atom = Value('apple');
Properties
Methods
-
match(
Node other) → Map< Variable, Node> ? -
Attempts to unify this node with
other, returning variable bindings ornull.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
Database database) → Iterable< Node> -
Evaluates this term as a goal against
database.override -
substitute(
Map< Variable, Node> ? bindings) → Value -
Substitutes variables in this node with their bound values in
bindings.override -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override