Variable class
A named Prolog variable capable of binding during unification.
Variable names begin with an uppercase letter or an underscore.
For example:
final x = Variable('X');
Properties
Methods
-
match(
Node other) → Map< Variable, Node> ? -
Attempts to unify this node with
other, returning variable bindings ornull.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
substitute(
Map< Variable, Node> ? bindings) → Node -
Substitutes variables in this node with their bound values in
bindings.override -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override