AsyncFunctionDefNode class
Asynchronous function definition statement (async def name(params): body).
- Inheritance
-
- Object
- PythonNode
- StatementNode
- AsyncFunctionDefNode
Constructors
-
AsyncFunctionDefNode({required String name, required ArgumentsNode args, required List<
StatementNode> body, List<ExpressionNode> decoratorList = const [], ExpressionNode? returns, List<TypeParamNode> typeParams = const []}) -
const
Properties
- args → ArgumentsNode
-
final
-
body
→ List<
StatementNode> -
final
-
decoratorList
→ List<
ExpressionNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- returns → ExpressionNode?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
typeParams
→ List<
TypeParamNode> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited