MatchCaseNode class
Match case in match statement (case pattern if guard: body).
- Inheritance
-
- Object
- PythonNode
- MatchCaseNode
Constructors
-
MatchCaseNode({required PatternNode pattern, ExpressionNode? guard, required List<
StatementNode> body}) -
const
Properties
-
body
→ List<
StatementNode> -
final
- guard → ExpressionNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pattern → PatternNode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited