MatchMappingNode class
Mapping pattern (case {"name": name, **rest}:).
- Inheritance
-
- Object
- PythonNode
- PatternNode
- MatchMappingNode
Constructors
-
MatchMappingNode({List<
ExpressionNode> keys = const [], List<PatternNode> patterns = const [], String? rest}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keys
→ List<
ExpressionNode> -
final
-
patterns
→ List<
PatternNode> -
final
- rest → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited