TypeAliasNode class
PEP 695 type alias statement (type X[T] = int).
- Inheritance
-
- Object
- PythonNode
- StatementNode
- TypeAliasNode
Constructors
-
TypeAliasNode({required ExpressionNode name, required ExpressionNode value, List<
TypeParamNode> typeParams = const []}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → ExpressionNode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
typeParams
→ List<
TypeParamNode> -
final
- value → ExpressionNode
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited