IntersectionNode class
An AST node matching the intersection of left and right (the & operator).
Note: Compilation to an Nfa is currently unsupported for intersection nodes.
Constructors
- IntersectionNode(Node left, Node right)
-
Creates an intersection of
leftandright.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNfa(
) → Nfa -
Compiles this AST node into a nondeterministic finite automaton (Nfa).
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override