NfaState class
A state within a nondeterministic finite automaton (Nfa).
Constructors
Properties
-
dots
→ List<
NfaState> -
Wildcard (any character) transition states.
final
-
endAnchors
→ List<
NfaState> -
End-of-input anchor transition states.
final
-
epsilons
→ List<
NfaState> -
Epsilon (empty string) transition states.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEnd ↔ bool
-
Whether this state is an accepting (terminal) state.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
startAnchors
→ List<
NfaState> -
Start-of-input anchor transition states.
final
-
transitions
→ Map<
int, NfaState> -
Map of character code points to subsequent transition states.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited