QuantificationNode class
An AST node repeating child between min and max times.
If max is null, the repetition is unbounded (such as * or +).
Constructors
- QuantificationNode(Node child, int min, [int? max])
-
Creates a quantification of
childwithminand optionalmaxbounds.
Properties
- child → Node
-
The child node being quantified.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- max → int?
-
The optional maximum number of repetitions, or
nullif unbounded.final - min → int
-
The minimum number of repetitions.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNfa(
) → Nfa -
Compiles this AST node into a nondeterministic finite automaton (Nfa).
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override