RangeNode class
An AST node matching any character within the inclusive range between startCodePoint and endCodePoint.
Properties
- endCodePoint → int
-
The inclusive upper-bound Unicode code point.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startCodePoint → int
-
The inclusive lower-bound Unicode code point.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNfa(
) → Nfa -
Compiles this AST node into a nondeterministic finite automaton (Nfa).
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override