RegexpMatch class
A Match produced by a RegexpPattern.
- Implemented types
Constructors
- RegexpMatch(Pattern pattern, String input, int start, int end)
-
Creates a match for
patternagainstinputspanning fromstarttoend.
Properties
- end → int
-
The index in the string after the last character of the match.
final
- groupCount → int
-
Returns the number of captured groups in the match.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → String
-
The string on which this match was computed.
final
- pattern → Pattern
-
The pattern used to search in input.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int
-
The index in the string where the match starts.
final
Methods
-
group(
int group) → String? -
The string matched by the given group.
override
-
groups(
List< int> groupIndices) → List<String?> -
A list of the groups with the given indices.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int group) → String? -
The string matched by the given
group.override