RegexpParserDefinition class
Grammar definition parsing regular expression syntax into a Node AST.
Supports literal characters, character classes ([...]), ranges ([a-z]),
complements ([^...] and !), wildcards (.), anchors (^, $),
quantification (*, +, ?, {min,max}), concatenations,
alternations (|), and intersections (&).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → Parser< Node> -
Builds the default composite parser starting at
start.inherited -
buildFrom<
T> (Parser< T> parser) → Parser<T> -
Builds a composite parser starting with the specified
parser.inherited -
charClass(
) → Parser< Node> -
charClassChar(
) → Parser< String> -
charClassItem(
) → Parser< Node> -
charClassItems(
) → Parser< Node> -
charClassRange(
) → Parser< Node> -
dot(
) → Parser< Node> -
endAnchor(
) → Parser< Node> -
escape(
) → Parser< Node> -
integer(
) → Parser< int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
other(
) → Parser< Node> -
range(
) → Parser< ({int? max, int min})> -
start(
) → Parser< Node> - Returns the starting production of this definition.
-
startAnchor(
) → Parser< Node> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited