BlockNode class
An AST node representing a Smalltalk block closure ([ :arg | arg + 1 ]).
Constructors
- BlockNode(SequenceNode body)
-
Creates a block closure node with
body.
Properties
-
afterToken
→ List<
Token> -
Closing boundary tokens.
finalinherited
-
arguments
→ List<
VariableNode> -
Block parameter variables declared with leading colons (e.g.
:x).final -
beforeToken
→ List<
Token> -
Opening boundary tokens.
finalinherited
- body → SequenceNode
-
The statements sequence inside the block.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
separators
→ List<
Token> -
Vertical bar separators (
|) following block arguments.final
Methods
-
accept(
Visitor visitor) → void -
Dispatches execution to
visitorbased on concrete node type.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
surroundWith(
Token before, Token after) → void -
Records enclosing
beforeandaftertokens.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited