HasStatements mixin
Mixin for AST nodes that contain a sequence of statements and separator periods.
- Implemented types
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
periods
→ List<
Token> -
The period tokens separating statements.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statements
→ List<
IsStatement> -
The statements contained within this node.
final
Methods
-
accept(
Visitor visitor) → void -
Dispatches execution to
visitorbased on concrete node type.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited