LiteralNode<T> class abstract

Base class for literal constants in Smalltalk.

Inheritance
Implementers

Constructors

LiteralNode(T value)
Creates a literal node holding value.

Properties

afterToken → List<Token>
Closing boundary tokens.
finalinherited
beforeToken → List<Token>
Opening boundary tokens.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → T
The literal value.
final

Methods

accept(Visitor visitor) → void
Dispatches execution to visitor based on concrete node type.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
surroundWith(Token before, Token after) → void
Records enclosing before and after tokens.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited