PragmaNode class
An AST node representing a method annotation or compiler pragma (<primitive: 123>).
- Inheritance
- Mixed-in types
Constructors
- PragmaNode()
- Creates a pragma node.
Properties
-
afterToken
→ List<
Token> -
Closing boundary tokens.
finalinherited
-
arguments
→ List<
LiteralNode> -
The arguments associated with this selector.
final
-
beforeToken
→ List<
Token> -
Opening boundary tokens.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selector → String
-
The full selector string combined from selectorToken.
no setterinherited
-
selectorToken
→ List<
Token> -
Tokens comprising the selector name.
finalinherited
- selectorType → SelectorType
-
The dispatch category of this selector.
no setterinherited
Methods
-
accept(
Visitor visitor) → void -
Dispatches execution to
visitorbased on concrete node type.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
surroundWith(
Token before, Token after) → void -
Records enclosing
beforeandaftertokens.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited