SequenceNode class
An AST node representing a block or method body containing temporaries and statements.
- Inheritance
- Mixed-in types
Constructors
- SequenceNode()
- Creates a sequence node.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
periods
→ List<
Token> -
The period tokens separating statements.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statements
→ List<
IsStatement> -
The statements contained within this node.
finalinherited
-
temporaries
→ List<
VariableNode> -
Local temporary variables declared in
| temp1 temp2 |.final
Methods
-
accept(
Visitor visitor) → void -
Dispatches execution to
visitorbased on concrete node type.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited