ValueNode class abstract
Abstract base class for AST expressions that produce a value.
- Inheritance
- Mixed-in types
- Implementers
Constructors
- ValueNode()
- Creates a value node.
Properties
-
afterToken
→ List<
Token> -
Closing boundary tokens.
finalinherited
-
beforeToken
→ List<
Token> -
Opening boundary tokens.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept(
Visitor visitor) → void -
Dispatches execution to
visitorbased on concrete node type.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
surroundWith(
Token before, Token after) → void -
Records enclosing
beforeandaftertokens.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited