TabularDefinition class
Customizable parser definition for tabular text files.
Constructors
-
TabularDefinition({required Parser<
String> quote, required Parser<String> escape, required Parser<String> delimiter, required Parser<String> newline}) - Generic constructor for tabular text files.
- TabularDefinition.csv()
-
Definition for "Comma-separated values" (CSV) input.
factory
- TabularDefinition.tsv()
-
Definition for "Tab-separated values" (TSV) input.
factory
Properties
-
delimiter
→ Parser<
String> -
Specifies how values are delimited in a row.
final
-
escape
→ Parser<
String> -
Specifies how characters are escaped.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
newline
→ Parser<
String> -
Specifies how rows are delimited in a file.
final
-
quote
→ Parser<
String> -
Specifies how values are quoted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → Parser< List< List< >String> > -
Builds the default composite parser starting at
start.inherited -
buildFrom<
T> (Parser< T> parser) → Parser<T> -
Builds a composite parser starting with the specified
parser.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Parser< List< List< >String> > - Returns the starting production of this definition.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited